/*
 * This file contains declarations for the low level routines for the
 * TIEPIE scopes/generators.
 * written by Hans de Vries - University of Technology Eindhoven - the Netherlands
 * Questions/remarks/error-reports : H.P.d.Vries@stud.tue.nl
 */

#ifndef __TIEPIE_DEFINED
#define __TIEPIE_DEFINED
 
#include <dos.h>
#include <windows.h>

/* declarations to match pascal-types to c-types */
typedef unsigned char byte;
typedef unsigned int  dword;
typedef unsigned short int word;
typedef signed long int integer;


/* Error-codes */
#define E_INVALID_VALUE 0x0020
#define E_INVALID_CHANNEL 0x0010
#define E_NO_GENERATOR 0x0008
#define E_NOT_SUPPORTED 0x0004
#define E_NOT_INITIALISED 0x0002
#define E_NO_HARDWARE 0x0001
#define E_NO_ERRORS 0x0000


void InitFunctions(HINSTANCE MyDLL);

/* Declarations for functions from dynamically loaded librarie(s) */

word (WINAPI*InitInstrument) (word);
word (WINAPI*ExitInstrument) (void);

word (WINAPI*GetCalibrationDate) (dword*);
word (WINAPI*GetSerialNumber) (dword*);

dword (WINAPI*GetMaxSampleFrequency) (void);
dword (WINAPI*GetMaxRecordLength) (void);

word (WINAPI*GetSquareWaveGenStatus) (void);
word (WINAPI*GetFunctionGenStatus) (void);
word (WINAPI*GetFuncGenMaxAmplitude) (double*);

word (WINAPI*StartMeasurement) (void);

word (WINAPI*GetMeasurement) (double*, double*);
word (WINAPI*GetOneMeasurement) (integer, double*, double*);

word (WINAPI*GetMeasurementRaw) (word*, word*);
word (WINAPI*GetOneMeasurementRaw) (integer, word*, word*);

word (WINAPI*GetDigitalInputValues) (word*);
word (WINAPI*GetOneDigitalValue) (word, word*);

word (WINAPI*GetMeasureMode) (byte*);
word (WINAPI*SetMeasureMode) (byte);

dword (WINAPI*GetRecordLength) (void);
dword (WINAPI*SetRecordLength) (word);

word (WINAPI*GetPostSamples) (void);
word (WINAPI*SetPostSamples) (word);

dword (WINAPI*GetSampleFrequency) (void);
word (WINAPI*SetSampleFrequency) (dword*);

word (WINAPI*GetSensitivity) (byte, double*);
word (WINAPI*SetSensitivity) (byte, double*);

word (WINAPI*GetAutoRanging) (byte, byte*);
word (WINAPI*SetAutoRanging) (byte, byte);

word (WINAPI*GetCoupling) (byte, byte*);
word (WINAPI*SetCoupling) (byte, byte);

word (WINAPI*GetDcLevel) (byte, double*);
word (WINAPI*SetDcLevel) (byte, double);

word (WINAPI*GetTriggerSource) (byte*);
word (WINAPI*SetTriggerSource) (byte);

word (WINAPI*GetTriggerMode) (byte*);
word (WINAPI*SetTriggerMode) (byte);

word (WINAPI*GetTriggerLevel) (byte, double*);
word (WINAPI*SetTriggerLevel) (byte, double);

word (WINAPI*GetTriggerHys) (byte, double*);
word (WINAPI*SetTriggerHys) (byte, double);

word (WINAPI*SetPXITriggerEnables) (byte);
word (WINAPI*GetPXITriggerEnables) (byte*);

word (WINAPI*SetPXITriggerSlopes) (byte);
word (WINAPI*GetPXITriggerSlopes) (byte*);

dword (WINAPI*GetTriggerTimeOut) (void);
byte (WINAPI*SetTriggerTimeOut) (dword);

word (WINAPI*SetDigitalOutputs) (byte);
word (WINAPI*GetDigitalOutputs) (byte*);

double (WINAPI*GetSquareWaveGenFrequency) (void);
word (WINAPI*SetSquareWaveGenFrequency) (double*);

word (WINAPI*SetFuncGenSignalType) (word);
word (WINAPI*GetFuncGenSignalType) (word*);

word (WINAPI*SetFuncGenAmplitude) (double);
word (WINAPI*GetFuncGenAmplitude) (double*);

word (WINAPI*SetFuncGenDCOffset) (double);
word (WINAPI*GetFuncGenDCOffset) (double*);

word (WINAPI*SetFuncGenSymmetry) (double);
word (WINAPI*GetFuncGenSymmetry) (double*);

word (WINAPI*SetFuncGenFrequency) (double*);
word (WINAPI*GetFuncGenFrequency) (double*);

word (WINAPI*FillFuncGenMemory) (word, word*);

word (WINAPI*SetFuncGenOutputOn) (word);
word (WINAPI*GetFuncGenOutputOn) (word*);

#endif